
# Slot: contributor




URI: [biolink:contributor](https://w3id.org/biolink/vocab/contributor)


## Domain and Range

[InformationContentEntity](InformationContentEntity.md) &#8594;  <sub>0..\*</sub> [Agent](Agent.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [author](author.md)
 *  [editor](editor.md)
 *  [provider](provider.md)
 *  [publisher](publisher.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | This is a grouping for predicates relating entities to their associated contributors realizing them |
| **Exact Mappings:** | | dct:contributor |

